@@ -1,6 +1,5 @@
 /* charpick.h -- header file for character picker applet */
 
-#include <config.h>
 #include <gnome.h>
 #include <panel-applet.h>
 #include <panel-applet-gconf.h>
@@ -45,6 +44,8 @@ void start_callback_update();
 
 void build_table(charpick_data *curr_data);
 void property_show(BonoboUIComponent *uic, gpointer data, const gchar *verbname);
+void set_atk_name_description(GtkWidget *widget, const gchar *name,
+                              const gchar *description);
 
 
 
