@@ -25,6 +25,7 @@
 #include <libgnomeui/libgnomeui.h>
 #include <panel-applet.h>
 #include <panel-applet-gconf.h> 
+#include <gconf/gconf-client.h>
 #include <gtk/gtk.h>
 #include <time.h>
 
@@ -91,6 +92,11 @@
 		/*  properties vars */
  	 
 		GtkWidget *tik_syms_entry;
+		GtkWidget *proxy_url_entry;
+		GtkWidget *proxy_port_entry;
+		GtkWidget *proxy_user_entry;
+		GtkWidget *proxy_passwd_entry;
+		GtkWidget *proxy_auth_button;
 
 		GtkWidget *fontDialog;
 
@@ -642,7 +648,8 @@ static gint updateOutput(gpointer data)
 		static const gchar *authors[] = {
 			"Jayson Lorenzen <jayson_lorenzen@yahoo.com>",
 			"Jim Garrison <garrison@users.sourceforge.net>",
-			"Rached Blili <striker@dread.net>"
+			"Rached Blili <striker@dread.net>",
+			NULL
 		};
 
 		about = gnome_about_new (_("The GNOME Stock Ticker"), VERSION,
@@ -800,7 +807,112 @@ static gint updateOutput(gpointer data)
 		}
 					     
 	}
+	
+	static void
+	proxy_toggled (GtkToggleButton *button, gpointer data)
+	{
+		StockData *stockdata = data;
+    		GConfClient *client = gconf_client_get_default ();
+    		gboolean toggled;	
+	
+    		toggled = gtk_toggle_button_get_active(button);
+    		gtk_widget_set_sensitive(stockdata->proxy_url_entry, toggled);
+    		gtk_widget_set_sensitive(stockdata->proxy_user_entry, toggled);
+    		gtk_widget_set_sensitive(stockdata->proxy_port_entry, toggled);
+    		gtk_widget_set_sensitive(stockdata->proxy_passwd_entry, toggled);
+    		gtk_widget_set_sensitive(stockdata->proxy_auth_button, toggled);
 
+    		gconf_client_set_bool (client, "/system/gnome-vfs/use-http-proxy", 
+    			   toggled, NULL);		
+	}	
+
+	static gboolean
+	proxy_port_changed (GtkWidget *entry, GdkEventFocus *event, gpointer data)
+	{
+    		GConfClient *client = gconf_client_get_default ();
+    		gchar *text;
+    		gint port;
+
+    		text = gtk_editable_get_chars (GTK_EDITABLE (entry), 0, -1);
+    
+    		if (!text) 
+    			return FALSE;
+    		port = atoi (text);
+    		g_free (text);
+    
+    		gconf_client_set_int (client, "/system/gnome-vfs/http-proxy-port", 
+    			  port, NULL);
+    		
+    		return FALSE;
+
+	}
+
+	static void
+	proxy_auth_toggled (GtkToggleButton *button, gpointer data)
+	{
+    		GConfClient *client = gconf_client_get_default ();
+    		gboolean toggled;
+	
+    		toggled = gtk_toggle_button_get_active(button);
+    		gconf_client_set_bool (client, "/system/gnome-vfs/use-http-proxy-authorization", 
+    			   toggled, NULL);
+	}
+
+	static gboolean
+	proxy_url_changed (GtkWidget *entry, GdkEventFocus *event, gpointer data)
+	{
+    		GConfClient *client = gconf_client_get_default ();
+    		gchar *text;
+
+    		text = gtk_editable_get_chars (GTK_EDITABLE (entry), 0, -1);
+    
+    		if (!text) 
+    			return FALSE;
+    
+    		gconf_client_set_string (client, "/system/gnome-vfs/http-proxy-host", 
+    			     text, NULL);
+    		g_free (text);
+    		
+    		return FALSE;	
+	}
+
+	static gboolean
+	proxy_user_changed (GtkWidget *entry, GdkEventFocus *event, gpointer data)
+	{
+    		GConfClient *client = gconf_client_get_default ();
+    		gchar *text;
+   
+    		text = gtk_editable_get_chars (GTK_EDITABLE (entry), 0, -1);
+    
+    		if (!text)
+   			return FALSE;
+
+    		gconf_client_set_string (client, "/system/gnome-vfs/http-proxy-authorization-user", 
+    			     text, NULL); 
+    		g_free (text);
+    		
+    		return FALSE;
+
+	}
+	
+	static gboolean
+	proxy_password_changed (GtkWidget *entry, GdkEventFocus *event, gpointer data)
+	{
+    		GConfClient *client = gconf_client_get_default ();
+    		gchar *text;
+   
+    		text = gtk_editable_get_chars (GTK_EDITABLE (entry), 0, -1);
+    
+    		if (!text)
+   			return FALSE;
+
+    		gconf_client_set_string (client, "/system/gnome-vfs/http-proxy-authorization-password", 
+    			     text, NULL);
+    		g_free (text);
+    		
+    		return FALSE;
+	}
+	
 	static void
 	add_symbol (GtkEntry *entry, gpointer data)
 	{
@@ -1053,7 +1165,7 @@ static gint updateOutput(gpointer data)
 		gtk_box_pack_end(GTK_BOX(vbox),hbox,FALSE,FALSE,0);
 	
 		mainhbox = gtk_hbox_new(FALSE,5);
-		gtk_box_pack_start(GTK_BOX(mainhbox),swindow,FALSE,FALSE,0);
+		gtk_box_pack_start(GTK_BOX(mainhbox),swindow,TRUE,TRUE,0);
 		gtk_box_pack_start(GTK_BOX(mainhbox),vbox,FALSE,FALSE,0);
 
 
@@ -1062,6 +1174,129 @@ static gint updateOutput(gpointer data)
 
 	}
 	
+	static GtkWidget *
+	create_proxy_box (StockData *stockdata)
+	{
+		GtkWidget *vbox;
+		GtkWidget *hbox, *button, *label;
+		GConfClient *client = gconf_client_get_default ();
+		gboolean use_proxy, use_proxy_auth;
+    		gint proxy_port;
+    		gchar *string;
+    		gchar *proxy_url, *proxy_user, *proxy_psswd;
+		
+		use_proxy = 
+    			gconf_client_get_bool (client, 
+    					       "/system/gnome-vfs/use-http-proxy", 
+    					       NULL);
+    		use_proxy_auth = gconf_client_get_bool (client, 
+    			"/system/gnome-vfs/use-http-proxy-authorization", 
+    			NULL);
+    		proxy_url = gconf_client_get_string (client, 
+    			"/system/gnome-vfs/http-proxy-host", NULL);
+    		proxy_user = gconf_client_get_string (client, 
+    		 	"/system/gnome-vfs/http-proxy-authorization-user", NULL);
+    		proxy_psswd = gconf_client_get_string (client, 
+    		 	"/system/gnome-vfs/http-proxy-authorization-password", NULL);
+    		proxy_port = gconf_client_get_int (client, 
+    		 	"/system/gnome-vfs/http-proxy-port", NULL);
+		
+		vbox = gtk_vbox_new (FALSE, 4);
+		gtk_container_set_border_width (GTK_CONTAINER (vbox), 8);
+		
+		button = gtk_check_button_new_with_label (_("Use HTTP proxy"));
+    		gtk_box_pack_start (GTK_BOX (vbox), button, 
+    				    FALSE, FALSE, 0);
+    		gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (button), use_proxy);
+   		g_signal_connect (G_OBJECT (button), "toggled",
+    		       		  G_CALLBACK (proxy_toggled), stockdata);
+
+    		hbox = gtk_hbox_new (FALSE, 2);
+    		gtk_box_pack_start (GTK_BOX (vbox), hbox, FALSE, FALSE, 0);
+    
+    		label = gtk_label_new (_("Location :"));
+    		gtk_box_pack_start (GTK_BOX (hbox), label, 
+    			    FALSE, FALSE, 0);
+    
+    		stockdata->proxy_url_entry = gtk_entry_new ();
+    		gtk_widget_show (stockdata->proxy_url_entry);
+    		gtk_box_pack_start (GTK_BOX (hbox), stockdata->proxy_url_entry, 
+    			    FALSE, FALSE, 0);
+    		g_signal_connect (G_OBJECT (stockdata->proxy_url_entry), "focus_out_event",
+    		          G_CALLBACK (proxy_url_changed), stockdata);
+
+    		hbox = gtk_hbox_new (FALSE, 2);
+    		gtk_box_pack_start (GTK_BOX (vbox), hbox, FALSE, FALSE, 0);
+    
+    		label = gtk_label_new (_("Port :"));
+    		gtk_widget_show (label);
+    		gtk_box_pack_start (GTK_BOX (hbox), label, 
+    			    FALSE, FALSE, 0);
+    			
+    		stockdata->proxy_port_entry = gtk_entry_new ();
+    		gtk_box_pack_start (GTK_BOX (hbox), stockdata->proxy_port_entry, 
+    				    FALSE, FALSE, 0);
+    		g_signal_connect (G_OBJECT (stockdata->proxy_port_entry), "focus_out_event",
+    		          G_CALLBACK (proxy_port_changed), stockdata);
+    
+    		stockdata->proxy_auth_button = gtk_check_button_new_with_label (_("Proxy requires a uername and password"));
+    		gtk_box_pack_start (GTK_BOX (vbox), stockdata->proxy_auth_button, 
+    				    FALSE, FALSE, 0);
+    		gtk_toggle_button_set_active 
+    			(GTK_TOGGLE_BUTTON (stockdata->proxy_auth_button), use_proxy_auth);
+        	g_signal_connect (G_OBJECT (stockdata->proxy_auth_button), "toggled",
+    		       G_CALLBACK (proxy_auth_toggled), stockdata);
+    		       
+    		hbox = gtk_hbox_new (FALSE, 2);
+    		gtk_box_pack_start (GTK_BOX (vbox), hbox, FALSE, FALSE, 0);
+    
+    		label = gtk_label_new (_("Username:"));
+    		gtk_box_pack_start (GTK_BOX (hbox), label, 
+    			    FALSE, FALSE, 0);
+    
+    		stockdata->proxy_user_entry = gtk_entry_new ();
+    		gtk_box_pack_start (GTK_BOX (hbox), stockdata->proxy_user_entry, 
+    			    FALSE, FALSE, 0);
+    		g_signal_connect (G_OBJECT (stockdata->proxy_user_entry), "focus_out_event",
+    		          G_CALLBACK (proxy_user_changed), stockdata);
+
+    		hbox = gtk_hbox_new (FALSE, 2);
+    		gtk_box_pack_start (GTK_BOX (vbox), hbox, FALSE, FALSE, 0);
+    
+    		label = gtk_label_new (_("Password:"));
+    		gtk_box_pack_start (GTK_BOX (hbox), label, FALSE, FALSE, 0);
+
+    		stockdata->proxy_passwd_entry = gtk_entry_new ();
+    		gtk_entry_set_visibility (GTK_ENTRY (stockdata->proxy_passwd_entry), FALSE);
+    		gtk_box_pack_start (GTK_BOX (hbox), stockdata->proxy_passwd_entry, 
+    			    FALSE, FALSE, 0);
+    		g_signal_connect (G_OBJECT (stockdata->proxy_passwd_entry), 
+    			          "focus_out_event",
+    		                  G_CALLBACK (proxy_password_changed), stockdata);
+    		 	
+    		gtk_entry_set_text(GTK_ENTRY(stockdata->proxy_url_entry), 
+    		       proxy_url ? 
+    		       proxy_url : "");
+    		gtk_entry_set_text(GTK_ENTRY(stockdata->proxy_passwd_entry), 
+    		       proxy_psswd ? 
+    		       proxy_psswd : "");
+    		gtk_entry_set_text(GTK_ENTRY(stockdata->proxy_user_entry), 
+    		       proxy_user ? 
+    		       proxy_user : "");
+    		string = g_strdup_printf ("%d", proxy_port);
+    		gtk_entry_set_text(GTK_ENTRY(stockdata->proxy_port_entry), string);
+    		g_free (string); 
+    		
+    		gtk_widget_set_sensitive (stockdata->proxy_auth_button, use_proxy);
+    		gtk_widget_set_sensitive (stockdata->proxy_url_entry, use_proxy);
+    		gtk_widget_set_sensitive (stockdata->proxy_port_entry, use_proxy);
+    		gtk_widget_set_sensitive (stockdata->proxy_passwd_entry, use_proxy);
+    		gtk_widget_set_sensitive (stockdata->proxy_user_entry, use_proxy);
+    			
+		gtk_widget_show_all (vbox);
+		return vbox;
+	} 
+	
 	static void
 	response_cb (GtkDialog *dialog, gint id, gpointer data)
 	{
@@ -1078,7 +1313,7 @@ static gint updateOutput(gpointer data)
 		GtkWidget * notebook;
 		GtkWidget * vbox;
 		GtkWidget * vbox2;
-		GtkWidget * vbox3;
+		GtkWidget * vbox3, * vbox4;
 		GtkWidget * hbox3;
 		GtkWidget *hbox;
 		GtkWidget * label;
@@ -1219,6 +1454,8 @@ static gint updateOutput(gpointer data)
 		label5 = gtk_label_new(_("Stock Symbol:"));
 
 		font_picker = gnome_font_picker_new ();
+		gnome_font_picker_set_font_name (GNOME_FONT_PICKER (font_picker),
+						 stockdata->props.font);
 		gtk_box_pack_start_defaults(GTK_BOX(hbox3),label5);
                 gtk_box_pack_start_defaults(GTK_BOX(hbox3),font_picker);
                 gtk_box_pack_start_defaults(GTK_BOX(vbox3),hbox3);
@@ -1228,6 +1465,8 @@ static gint updateOutput(gpointer data)
 		hbox3 = gtk_hbox_new(FALSE, 5);
 		label5 = gtk_label_new(_("Stock Change:"));
                 font_picker = gnome_font_picker_new ();
+                gnome_font_picker_set_font_name (GNOME_FONT_PICKER (font_picker),
+						 stockdata->props.font2);
                 gtk_box_pack_start_defaults(GTK_BOX(hbox3),label5);
                 gtk_box_pack_start_defaults(GTK_BOX(hbox3),font_picker);
                 gtk_box_pack_start_defaults(GTK_BOX(vbox3),hbox3);
@@ -1252,6 +1491,9 @@ static gint updateOutput(gpointer data)
 		gtk_notebook_append_page (GTK_NOTEBOOK (notebook), vbox, label);
 		label = gtk_label_new_with_mnemonic (_("_Appearance"));
 		gtk_notebook_append_page (GTK_NOTEBOOK (notebook), vbox2, label);
+		label = gtk_label_new_with_mnemonic (_("_Proxy"));
+		vbox4 = create_proxy_box (stockdata);
+		gtk_notebook_append_page (GTK_NOTEBOOK (notebook), vbox4, label);
 
 		gtk_widget_show_all(stockdata->pb);
 		
