@@ -24,20 +24,29 @@
 #include "mini-commander_applet.h"
 
 
-void about_box(AppletWidget *applet, gpointer data)
-{
-        GtkWidget *about_box;
+/* void about_box(AppletWidget *applet, gpointer data) */
+
+void about_box(BonoboUIComponent *uic, gpointer data, const gchar *verbname){
+        static GtkWidget *about_box = NULL;
 	const gchar *authors[] = {(gchar *) "Oliver Maruhn <oliver@maruhn.com>", (gchar *) NULL};
 
+	if (about_box != NULL)
+	{
+		gdk_window_show(about_box->window);
+		gdk_window_raise(about_box->window);
+		return;
+	}
         about_box = gnome_about_new (_("Mini-Commander Applet"), 
-				    VERSION,
-				    "(C) 1998-2000 Oliver Maruhn",
-				    authors,
+				     VERSION,
+				     "(C) 1998-2002 Oliver Maruhn",
 _("This GNOME applet adds a command line to the panel. It features command completion, command history, changeable macros and an optional built-in clock.\n\n\
 This program is free software; you can redistribute it and/or modify it under the terms of the GNU General Public License as published by the Free Software Foundation; either version 2 of the License, or (at your option) any later version."),
-				    (gchar *) NULL);
+				     authors,
+				     NULL,
+				     NULL,
+				     NULL);
+	gtk_signal_connect( GTK_OBJECT(about_box), "destroy",
+			    GTK_SIGNAL_FUNC(gtk_widget_destroyed), &about_box );
         gtk_widget_show (about_box);
 	return;
-	applet = NULL;
-	data = NULL;
 }
