@@ -24,8 +24,8 @@
 #include <gnome.h>
 #include <panel-applet.h>
 #include <gdk/gdkkeysyms.h>
-/* include <zvt/zvtterm.h> */
 
+#include "mini-commander_applet.h"
 #include "command_line.h"
 #include "preferences.h"
 #include "exec.h"
@@ -37,19 +37,22 @@ static gint file_browser_ok_signal(GtkWidget *widget, gpointer file_select);
 /*static gint history_item_clicked_cb(GtkWidget *widget, gpointer data);*/
 static gint history_popup_clicked_cb(GtkWidget *widget, gpointer data);
 static gint history_popup_clicked_inside_cb(GtkWidget *widget, gpointer data);
-static void history_selection_made_cb(GtkWidget *clist, gint row, gint column,
-				    GdkEventButton *event, gpointer data);
+static void history_selection_made_cb (GtkTreeView *treeview, GtkTreePath *arg1,
+                                       GtkTreeViewColumn *arg2, gpointer data);
 static gchar* history_auto_complete(GtkWidget *widget, GdkEventKey *event);
 
 
-GtkWidget *entry_command = NULL;
 static int history_position = LENGTH_HISTORY_LIST;
 static char browsed_filename[300] = "";
 
+static GtkWidget *entry_command;
+
+
 static gint
 command_key_event(GtkWidget *widget, GdkEventKey *event, gpointer data)
 {
-    PanelApplet *applet = data;
+    MCData *mcdata = data;
+    PanelApplet *applet = mcdata->applet;
     properties *prop = g_object_get_data (G_OBJECT (applet), "prop");
     guint key = event->keyval;
     char *command;
@@ -59,10 +62,11 @@ command_key_event(GtkWidget *widget, GdkEventKey *event, gpointer data)
 
     /* printf("%d,%d,%d;  ", (gint16) event->keyval, event->state, event->length); */
 
-    if(key == GDK_Tab
+    if((key == GDK_Tab
        || key == GDK_KP_Tab
        || key == GDK_ISO_Left_Tab)
-	{
+       && event->state != GDK_SHIFT_MASK)
+	{	
 	    /* tab key pressed */
 	    strcpy(buffer, (char *) gtk_entry_get_text(GTK_ENTRY(widget)));
 	    cmd_completion(buffer, applet);
@@ -122,7 +126,7 @@ command_key_event(GtkWidget *widget, GdkEventKey *event, gpointer data)
 	    /* printf("%s\n", command); */
 	    exec_command(command, applet);
 
-	    append_history_entry((char *) command);
+	    append_history_entry(mcdata, (char *) command, FALSE);
 	    history_position = LENGTH_HISTORY_LIST;		   
 	    free(command);
 
@@ -198,8 +202,9 @@ command_line_activate_cb(GtkWidget *widget, GdkEvent *event, gpointer data)
 {
     /* Sometimes the text entry does not get the keyboard focus
        although it should.  This workaround fixes this problem. */
+#if 1
     gtk_widget_grab_focus(GTK_WIDGET(widget));
-
+#endif
     /* go on */
     return (FALSE);
     widget = NULL;
@@ -207,22 +212,31 @@ command_line_activate_cb(GtkWidget *widget, GdkEvent *event, gpointer data)
     data = NULL;
 }
 
-/* no longer needed */
 static void
-history_selection_made_cb(GtkWidget *clist, gint row, gint column,
-			GdkEventButton *event, gpointer data)
+history_selection_made_cb (GtkTreeView *treeview, GtkTreePath *arg1,
+                           GtkTreeViewColumn *arg2, gpointer data)
 {
     PanelApplet *applet = data;
     gchar *command;
+    GtkTreeModel *model;
+    GtkTreeIter iter;
+    GValue val = {0,};
+    GtkWidget *widget;
 
-    gtk_clist_get_text(GTK_CLIST(clist), row, column, &command);
+    widget = (GtkWidget *) treeview;
+    model = gtk_tree_view_get_model (treeview);
+    gtk_tree_model_get_iter ( model, &iter, arg1);
+    gtk_tree_model_get_value (GTK_TREE_MODEL (model), &iter,
+                              0, &val);
+    command = g_strdup (g_value_get_string (&val));
     exec_command(command, applet);
 
+    g_value_unset(&val);
+    g_free(command);
     /* close history window */
-    gtk_widget_destroy(GTK_WIDGET(clist->parent->parent->parent));
+    gtk_widget_destroy(GTK_WIDGET(widget->parent->parent->parent));
     return;
     data = NULL;
-    event = NULL;
 }
 
 #if 0
@@ -278,7 +292,12 @@ show_history_signal(GtkWidget *widget, gpointer data)
      GtkWidget *window;
      GtkWidget *frame;
      GtkWidget *scrolled_window;
-     GtkWidget *clist;
+     GtkListStore *store;
+     GtkTreeIter iter;
+     GtkTreeModel *model;
+     GtkWidget    *treeview;
+     GtkCellRenderer *cell_renderer;
+     GtkTreeViewColumn *column;
      /*Gtk_style *style;*/
      gchar *command_list[1];
      int i, j;
@@ -347,26 +366,38 @@ show_history_signal(GtkWidget *widget, gpointer data)
      
      gtk_widget_push_style (style);
      */
-     clist = gtk_clist_new(1);
      /*      gtk_widget_pop_style (); */
-     gtk_signal_connect(GTK_OBJECT(clist),
-			"select_row",
-			GTK_SIGNAL_FUNC(history_selection_made_cb),
-			applet);
-     
      
+     store = gtk_list_store_new (1, G_TYPE_STRING);
+
      /* add history entries to list */
      for(i = 0; i < LENGTH_HISTORY_LIST; i++)
 	 {
 	     if(exists_history_entry(i))
 		 {
 		     command_list[0] = get_history_entry(i);
-		     gtk_clist_append(GTK_CLIST(clist), command_list);
+                     gtk_list_store_append (store, &iter);
+                     gtk_list_store_set (store, &iter,0,command_list[0],-1);
 		 }
 	 }
-     gtk_container_add(GTK_CONTAINER(scrolled_window), clist);
-     gtk_widget_show(clist);    
      
+     model = GTK_TREE_MODEL(store);
+     treeview = gtk_tree_view_new_with_model (model);
+     cell_renderer = gtk_cell_renderer_text_new ();
+     column = gtk_tree_view_column_new_with_attributes (NULL, cell_renderer,
+                                                       "text", 0, NULL);
+     gtk_tree_view_append_column (GTK_TREE_VIEW (treeview), column);
+     gtk_tree_view_set_headers_visible (GTK_TREE_VIEW (treeview), FALSE);
+     gtk_tree_selection_set_mode( (GtkTreeSelection *)gtk_tree_view_get_selection
+                                (GTK_TREE_VIEW (treeview)),
+                                 GTK_SELECTION_SINGLE);
+     gtk_signal_connect(GTK_OBJECT(treeview),
+                        "row_activated",
+                        GTK_SIGNAL_FUNC(history_selection_made_cb),
+                        applet);
+     g_object_unref (G_OBJECT (model));
+     gtk_container_add(GTK_CONTAINER(scrolled_window),treeview);
+     gtk_widget_show (treeview); 
      /* grab focus */
      gdk_pointer_grab (window->window,
 		       TRUE,
@@ -455,15 +486,20 @@ show_file_browser_signal(GtkWidget *widget, gpointer data)
     data = NULL;
 }
 
-void
-init_command_entry(PanelApplet *applet)
+GtkWidget *
+init_command_entry(MCData *mcdata)
 {
-    properties *prop = g_object_get_data (G_OBJECT (applet), "prop");
+    PanelApplet *applet = mcdata->applet;
+    properties *prop = mcdata->prop;
+    
     if(entry_command)
     	gtk_widget_destroy(GTK_WIDGET(entry_command));    
     
     /* create the widget we are going to put on the applet */
     entry_command = gtk_entry_new_with_max_length((guint16) MAX_COMMAND_LENGTH); 
+    set_atk_name_description (entry_command, _("Command line"), 
+        _("Type a command here and Gnome will execute it for you"));
+        
     /* in case we get destroyed elsewhere */
     gtk_signal_connect(GTK_OBJECT(entry_command),"destroy",
 		       GTK_SIGNAL_FUNC(gtk_widget_destroyed),
@@ -471,7 +507,7 @@ init_command_entry(PanelApplet *applet)
     
     gtk_signal_connect(GTK_OBJECT(entry_command), "key_press_event",
 		       GTK_SIGNAL_FUNC(command_key_event),
-		       applet);
+		       mcdata);
 
 #if 0
     gtk_signal_connect(GTK_OBJECT(entry_command), "focus_out_event",
@@ -481,47 +517,42 @@ init_command_entry(PanelApplet *applet)
 		       GTK_SIGNAL_FUNC(command_line_focus_in_cb),
 		       NULL);
 #endif
-
+#if 1
     gtk_signal_connect(GTK_OBJECT(entry_command), "button_press_event",
 		       GTK_SIGNAL_FUNC(command_line_activate_cb),
-		       applet);
+		       mcdata);
+#endif    
+    command_entry_update_color(entry_command, prop);
+    command_entry_update_size(entry_command, prop);
     
-    command_entry_update_color(prop);
-    command_entry_update_size(prop);
+    return entry_command;
 }
 
 
 void
-command_entry_update_color(properties *prop)
+command_entry_update_color(GtkWidget *entry_command, properties *prop)
 {
-    GtkStyle *style;
-    
-    /* change widget style */
-    /* style = malloc(sizeof(Gtk_style)); */
-    gtk_widget_ensure_style(entry_command);
-    style = gtk_style_copy(gtk_widget_get_style(entry_command));
-    
-    /* set text color */
-    style->text[GTK_STATE_NORMAL].red = (gushort) prop->cmd_line_color_fg_r;
-    style->text[GTK_STATE_NORMAL].green = (gushort) prop->cmd_line_color_fg_g;
-    style->text[GTK_STATE_NORMAL].blue = (gushort) prop->cmd_line_color_fg_b;
+    GdkColor fg, bg;
 
-    /* does someone know how to set the color of the cursor? */
-
-    /* set background color */
-    style->base[GTK_STATE_NORMAL].red = (gushort) prop->cmd_line_color_bg_r;
-    style->base[GTK_STATE_NORMAL].green = (gushort) prop->cmd_line_color_bg_g;
-    style->base[GTK_STATE_NORMAL].blue = (gushort) prop->cmd_line_color_bg_b;
-    
-    gtk_widget_set_style(entry_command, style);
+    fg.red = prop->cmd_line_color_fg_r;
+    fg.green = prop->cmd_line_color_fg_g;
+    fg.blue = prop->cmd_line_color_fg_b;
+    bg.red = prop->cmd_line_color_bg_r;
+    bg.green = prop->cmd_line_color_bg_g;
+    bg.blue = prop->cmd_line_color_bg_b;
+    gtk_widget_modify_text (entry_command, GTK_STATE_NORMAL, &fg);
+    gtk_widget_modify_text (entry_command, GTK_STATE_PRELIGHT, &fg);
+    gtk_widget_modify_base (entry_command, GTK_STATE_NORMAL, &bg);
+    gtk_widget_modify_base (entry_command, GTK_STATE_PRELIGHT, &bg);
+   
 }
 
 
 void
-command_entry_update_size(properties *prop)
+command_entry_update_size(GtkWidget *entry_command,properties *prop)
 {
     int size_y = -1;
-  
+
     if(prop->flat_layout)  {
 	if(prop->show_handle && !prop->show_frame)
 	    size_y = prop->normal_size_x - 17 - 10;
@@ -532,7 +563,6 @@ command_entry_update_size(properties *prop)
 	else if(!prop->show_handle && prop->show_frame)
 	    size_y = prop->normal_size_x - 17 - 10;
     }
-
     gtk_widget_set_usize(GTK_WIDGET(entry_command), size_y, prop->cmd_line_size_y);
 }
 
